@@ -8,12 +8,11 @@ from revscoring.datasources import Datasource
 from revscoring.datasources.meta import filters
 
 from .tokenized import TokenIsInTypes, is_uppercase_word
-from . import base
 
 logger = logging.getLogger(__name__)
 
 
-class Diff(base.BaseDiff):
+class Diff:
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
@@ -122,14 +121,14 @@ class Diff(base.BaseDiff):
         """
 
         self.cjks_added = self.tokens_added_in_types(
-            {'cjk_word'}, name=self._name + ".cjks_added"
+            {'cjk'}, name=self._name + ".cjks_added"
         )
         """
         A list of Chinese/Japanese/Korean tokens added in the edit
         """
 
         self.cjks_removed = self.tokens_removed_in_types(
-            {'cjk_word'}, name=self._name + ".cjks_removed"
+            {'cjk'}, name=self._name + ".cjks_removed"
         )
         """
         A list of Chinese/Japanese/Korean tokens removed in the edit
