@@ -3,10 +3,8 @@ from deltas.segmenters import MatchableSegment
 from revscoring.datasources import Datasource
 from revscoring.datasources.meta import indexable
 
-from . import base
 
-
-class Revision(base.BaseRevision):
+class Revision:
 
     def __init__(self, name, revision_datasources):
         super().__init__(name, revision_datasources)
@@ -20,7 +18,7 @@ class Revision(base.BaseRevision):
         """
 
 
-class Diff(base.BaseDiff):
+class Diff():
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
