@@ -1,14 +1,15 @@
 from itertools import groupby
+
 from revscoring.datasources.meta import mappers
+
 from ...feature import Feature
 from ...meta import aggregators
-from . import base
 
 
-class Revision(base.BaseRevision):
+class Revision:
 
-    def __init__(self, name, revision_datasources):
-        super().__init__(name, revision_datasources)
+    def __init__(self, *args, **kwargs):
+        super().__init__(*args, **kwargs)
 
         self.chars = aggregators.len(
             self.datasources.text,
@@ -73,7 +74,7 @@ class Revision(base.BaseRevision):
         "`int` : The most repeated character"
 
 
-class Diff(base.BaseDiff):
+class Diff:
 
     def __init__(self, *args, **kwargs):
         super().__init__(*args, **kwargs)
